@@ -13,13 +13,13 @@ from nonebot.adapters.onebot.v11 import (
     LuckyKingNotifyEvent
 )
 
-from .chuoyichuo import chuo_send_msg
-from .rongyu import monitor_rongyu
+from .stamp import *
+from .honour import *
 from .admin import *
 
 
 # 获取戳一戳状态
-async def _is_poke(bot: Bot, event: Event, state: T_State) -> bool:
+async def _is_poke(event: Event, state: T_State) -> bool:
     return isinstance(event, PokeNotifyEvent) and event.is_tome()
 
 
@@ -56,7 +56,7 @@ async def _is_red_packet(bot: Bot, event: Event, state: T_State) -> bool:
 # 戳一戳
 chuo = on_notice(Rule(_is_poke), priority=50, block=True)
 # 群荣誉
-rongyu = on_notice(Rule(_is_rongyu), priority=50, block=True)
+qrongyu = on_notice(Rule(_is_rongyu), priority=50, block=True)
 # 群文件
 files = on_notice(Rule(_is_checker), priority=50, block=True)
 # 群员减少
@@ -64,28 +64,34 @@ del_user = on_notice(Rule(_is_del_user), priority=50, block=True)
 # 群员增加
 add_user = on_notice(Rule(_is_add_user), priority=50, block=True)
 # 群管理
-admin = on_notice(Rule(_is_admin_change), priority=50, block=True)
+group_admin = on_notice(Rule(_is_admin_change), priority=50, block=True)
 # 红包
 red_packet = on_notice(Rule(_is_red_packet), priority=50, block=True)
 
 
 @chuo.handle()
 async def send_chuo(bot: Bot, event: Event, state: T_State):
+    if bot_name == "寄":
+        await chuo.finish("请先配置bot_name")
     rely_msg = chuo_send_msg()
     await chuo.finish(message=Message(rely_msg))
 
 
-@rongyu.handle()
+@qrongyu.handle()
 async def send_rongyu(bot: Bot, event: HonorNotifyEvent, state: T_State):
+    if bot_qq == "寄":
+        await qrongyu.finish("请先配置bot_qq")
+    if super_qq == "寄":
+        await qrongyu.finish("请先配置SUPERUSERS")
     rely_msg = monitor_rongyu(event.honor_type, event.user_id)
-    await send_rongyu.finish(message=Message(rely_msg))
+    await qrongyu.finish(message=Message(rely_msg))
 
 
 @files.handle()
 async def handle_first_receive(bot: Bot, event: GroupUploadNoticeEvent, state: T_State):
     rely = f'[CQ:at,qq={event.user_id}]\n' \
            f'[CQ:image,file=https://q4.qlogo.cn/headimg_dl?dst_uin={event.user_id}&spec=640]' \
-           f'\n 上传了新文件，感谢你一直为群里做贡献[CQ:face,id=175]'
+           f'\n 上传了新文件，感谢你一直为群里做贡献喵~[CQ:face,id=175]'
     await files.finish(message=Message(rely))
 
 
@@ -101,10 +107,10 @@ async def user_welcome(bot: Bot, event: GroupIncreaseNoticeEvent, state: T_State
     await add_user.finish(message=Message(rely_msg))
 
 
-@admin.handle()
+@group_admin.handle()
 async def admin_chance(bot: Bot, event: GroupAdminNoticeEvent, state: T_State):
-    rely_msg = admin_change(event.sub_type, event.user_id)
-    await bot.finish(message=Message(rely_msg))
+    rely_msg = admin_changer(event.sub_type, event.user_id)
+    await group_admin.finish(message=Message(rely_msg))
 
 @red_packet.handle()
 async def hongbao(bot: Bot, event: LuckyKingNotifyEvent, state: T_State):
